@@ -16,13 +16,9 @@ from photutils.segmentation import SourceCatalog
 
 from pyBIA import data_processing
 
-#hdu = fits.open('/Users/daniel/Desktop/NDWFS_Tiles/Bw_FITS/NDWFSJ1426p3236_Bw_03_fix.fits')
-#data = hdu[0].data
-
-
 def create(data, error=None, morph_params=False, x=None, y=None, name=None,
     aperture=15, annulus_in=20, annulus_out=35, invert=False, nsig=2, 
-    path=''):
+    save_file=True, path=''):
     """
     Creates a photometric and morphological catalog containing the object(s) in 
     the given position(s) at the given order. The parameters x and y should be 1D 
@@ -69,6 +65,9 @@ def create(data, error=None, morph_params=False, x=None, y=None, name=None,
         nsig (int): Objects in the image are detected if their peak intensity is
             higher than at least nsig times the standard deviation derived from
             sigma-clipped statistics. Default is 2.
+        save_file (bool): If set to False then the catalog will not be saved to the machine. 
+            You can always save manually, for example, if df = catalog(), then you can save 
+            with: df.to_csv('filename'). Defaults to True.
         path (str, optional): By default the text file containing the photometry will be
             saved to the local directory, unless an absolute path to a desired
             directory is entered here.
@@ -85,8 +84,9 @@ def create(data, error=None, morph_params=False, x=None, y=None, name=None,
         where surrounding sources may skew the median background.
                 
     Returns:
-        A catalog of all objects input (or automatically detected if there were no position arguments), containing
-        both photometric and morphological information. 
+        A catalog of all objects input (or automatically detected if there were no position arguments), 
+        containing both photometric and morphological information. A CSV file titled "pybia_catalog" 
+        will also be saved to the local directory, unless an absolute path argument is specified.
           
     """
     
@@ -103,7 +103,8 @@ def create(data, error=None, morph_params=False, x=None, y=None, name=None,
         if len(x) != len(y):
             raise ValueError("The two position arrays (x & y) must be the same size.")
     if invert == False:
-        warn('WARNING: Is your data from a .fits file? If so you may need to set invert=True if (x,y) = (0,0) is at the top left corner of the image instead of the bottom left corner.')
+        warn('WARNING: Is your data from a .fits file? If so you may need to set invert=True if (x,y) = (0,0) \
+            is at the top left corner of the image instead of the bottom left corner.')
     if x is None: #Apply DAOFIND (Stetson 1987) to detect sources in the image
         mean, median, std = sigma_clipped_stats(data, sigma=3.0)
         print('Performing source detection -- this will take several minutes...')
@@ -131,10 +132,10 @@ def create(data, error=None, morph_params=False, x=None, y=None, name=None,
         if morph_params == True:
             prop_list = morph_parameters(data, x, y, invert=invert)
             tbl = make_table(prop_list)
-            df = make_dataframe(table=tbl, x=x, y=y, name=name, flux=flux, save=True, path=path)
+            df = make_dataframe(table=tbl, x=x, y=y, name=name, flux=flux, save=save_file, path=path)
             return df
 
-        df = make_dataframe(table=None, x=x, y=y, name=name, flux=flux, save=True, path=path)
+        df = make_dataframe(table=None, x=x, y=y, name=name, flux=flux, save=save_file, path=path)
         return df
        
     phot_table = aperture_photometry(data, apertures, error=error)
@@ -143,10 +144,10 @@ def create(data, error=None, morph_params=False, x=None, y=None, name=None,
     if morph_params == True:
         prop_list = morph_parameters(data, x, y, invert=invert)
         tbl = make_table(prop_list)
-        df = make_dataframe(table=tbl, x=x, y=y, name=name, flux=flux, flux_err=flux_err, save=True, path=path)
+        df = make_dataframe(table=tbl, x=x, y=y, name=name, flux=flux, flux_err=flux_err, save=save_file, path=path)
         return df
 
-    df = make_dataframe(table=None, x=x, y=y, name=name, flux=flux, flux_err=flux_err, save=True, path=path)
+    df = make_dataframe(table=None, x=x, y=y, name=name, flux=flux, flux_err=flux_err, save=save_file, path=path)
     return df
 
 
@@ -211,7 +212,8 @@ def morph_parameters(data, x, y, invert=False, nsig=2):
         try:
             props = SourceCatalog(new_data, segm, kernel=kernel)
         except:
-            warn('Skipping at least one object which could not be detected in segmentation... perhaps too faint or coordinate error.')
+            warn('At least one object which could not be detected in segmentation... perhaps too object is too faint \
+                or there is a coordinate error.')
             continue
 
         sep_list=[]
@@ -240,7 +242,7 @@ def make_table(props):
         Props (source catalog): A source catalog containing morphological parameters.
         
     Returns:
-        ndarray: Array containing the morphological features. 
+        Array containing the morphological features. 
 
     """
 
@@ -286,7 +288,7 @@ def make_table(props):
     return np.array(table)
 
 def make_dataframe(table, x=None, y=None, flux=None, flux_err=None, name=None,
-    save=True, path=None):
+    save=True, path=None, save_image=False):
     """
     This function takes as input the catalog of morphological features
     which is output by the make_cat_tbl function -- this catalog is converted
@@ -294,7 +296,7 @@ def make_dataframe(table, x=None, y=None, flux=None, flux_err=None, name=None,
 
 
     Args:
-        tbl: Table containing the object features. Can make with make_table() function.
+        table: Table containing the object features. Can make with make_table() function.
         x (array, optional): 1D array containing the x-pixel position.
             If input it must be an array of x positions for all objects in the table. 
             This x position will be appended to the dataframe for cataloging purposes. Defaults to None.
@@ -322,9 +324,9 @@ def make_dataframe(table, x=None, y=None, flux=None, flux_err=None, name=None,
         >>> dataframe = make_dataframe(table, x=xpix, y=ypix)
 
     Returns:
-        dataframe: Pandas dataframe containing the parameters and features of all objects
-            in the input data table
-        csv: CSV file titled "pybia_catalog" if save=True.
+        Pandas dataframe containing the parameters and features of all objects
+        in the input data table. If save=True, a CSV file titled 'pybia_catalog'
+        will be saved to the local directory, unless a path is specified.
 
     """
 
@@ -346,7 +348,7 @@ def make_dataframe(table, x=None, y=None, flux=None, flux_err=None, name=None,
         data_dict['flux'] = flux
     if flux_err is not None:
         data_dict['flux_err'] = flux_err
-
+    
     if table is None:
         df = pd.DataFrame(data_dict)
         if save == True:
@@ -371,4 +373,5 @@ def make_dataframe(table, x=None, y=None, flux=None, flux_err=None, name=None,
             return df
         df.to_csv('pyBIA_catalog')  
         return df
+    return df
 
